# Disclaimer

> "This document was produced with Cyberaide Bookmanager developed by Gregor von
> Laszewski available at
> [https://pypi.python.org/pypi/cyberaide-bookmanager](https://pypi.python.org/pypi/cyberaide-bookmanager).
> It is in the responsibility of the user to make sure an author acknowledgement
> section is included in your document. Copyright verification of content
> included  in a book is responsibility of the book editor."
